"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scriptRunner = exports.runner = exports.isWindows = void 0;
const node_process_1 = require("process");
const node_path_1 = require("path");
const get_runtime_js_1 = require("./get-runtime.js");
exports.isWindows = node_process_1.platform === 'win32';
const runner = (filename, configs) => {
    var _a, _b;
    const runtime = (0, get_runtime_js_1.getRuntime)(configs);
    if (runtime === 'bun')
        return ['bun'];
    if (runtime === 'deno') {
        const denoAllow = ((_a = configs === null || configs === void 0 ? void 0 : configs.deno) === null || _a === void 0 ? void 0 : _a.allow)
            ? configs.deno.allow
                .map((allow) => (allow ? `--allow-${allow}` : ''))
                .filter((allow) => allow)
            : [
                '--allow-read',
                '--allow-env',
                '--allow-run',
                '--allow-net',
                '--allow-hrtime',
            ];
        const denoDeny = ((_b = configs === null || configs === void 0 ? void 0 : configs.deno) === null || _b === void 0 ? void 0 : _b.deny)
            ? configs.deno.deny
                .map((deny) => (deny ? `--deny-${deny}` : ''))
                .filter((deny) => deny)
            : [];
        return ['deno', 'run', ...denoAllow, ...denoDeny];
    }
    
    return ['.ts', '.mts', '.cts'].includes((0, node_path_1.extname)(filename))
        ? [exports.isWindows ? 'npx.cmd' : 'npx', 'tsx']
        : ['node'];
};
exports.runner = runner;
const scriptRunner = (runner) => {
    var _a;
    const commands = {
        npm: [exports.isWindows ? 'npm.cmd' : 'npm', 'run'],
        bun: ['bun', 'run'],
        deno: ['deno', 'task'],
        yarn: ['yarn'],
        pnpm: ['pnpm', 'run'],
    };
    return (_a = commands === null || commands === void 0 ? void 0 : commands[runner]) !== null && _a !== void 0 ? _a : commands['npm'];
};
exports.scriptRunner = scriptRunner;
