"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parserOutput = exports.isDebug = exports.isQuiet = void 0;
const poku_js_1 = require("../configs/poku.js");
const regex = {
    ansi: /u001b\[0m|\n/i,
    skip: /\\u001b\[94m\\u001b\[1m◯/gi,
    todo: /\\u001b\[96m\\u001b\[1m●/gi,
};
const isQuiet = (configs) => typeof (configs === null || configs === void 0 ? void 0 : configs.quiet) === 'boolean' && Boolean(configs === null || configs === void 0 ? void 0 : configs.quiet);
exports.isQuiet = isQuiet;
const isDebug = (configs) => Boolean(configs === null || configs === void 0 ? void 0 : configs.debug);
exports.isDebug = isDebug;
const parserOutput = (options) => {
    const { output, result, configs } = options;
    const normalizedOutput = JSON.stringify(output);
    const hasSkip = normalizedOutput.match(regex.skip);
    if (hasSkip)
        poku_js_1.results.skip += hasSkip.length;
    const hasTodo = normalizedOutput.match(regex.todo);
    if (hasTodo)
        poku_js_1.results.todo += hasTodo.length;
    const debug = (0, exports.isDebug)(configs);
    const pad = (configs === null || configs === void 0 ? void 0 : configs.parallel) ? '  ' : '    ';
    const splittedOutput = output.split('\n');
    const outputs = (debug || !result
        ? splittedOutput
        : splittedOutput.filter((current) => {
            if (current.indexOf('Exited with code') !== -1)
                return false;
            return regex.ansi.test(JSON.stringify(current)) || current === '';
        })).filter((line) => (line === null || line === void 0 ? void 0 : line.trim().length) > 0);
    if (outputs.length === 0)
        return;
    return outputs.map((current) => `${pad}${current}`);
};
exports.parserOutput = parserOutput;
